@@ -103,7 +103,7 @@ format_date_and_time_x		(struct tm	*date_tm,
 	
 	/* Calculate a normalized "tomorrow" */
 	tomorrow_tm = *current_tm;
-	if (tomorrow_tm.tm_mday == time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
+	if (tomorrow_tm.tm_mday == time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1)) {
 		tomorrow_tm.tm_mday = 1;
 		if (tomorrow_tm.tm_mon == 11) {
 			tomorrow_tm.tm_mon = 1;
@@ -117,8 +117,8 @@ format_date_and_time_x		(struct tm	*date_tm,
 
 	/* Calculate a normalized "next seven days" */
 	week_tm = *current_tm;
-	if (week_tm.tm_mday + 6 > time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon)) {
-		week_tm.tm_mday = (week_tm.tm_mday + 6) % time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon);
+	if (week_tm.tm_mday + 6 > time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1)) {
+		week_tm.tm_mday = (week_tm.tm_mday + 6) % time_days_in_month (date_tm->tm_year + 1900, date_tm->tm_mon - 1);
 		if (week_tm.tm_mon == 11) {
 			week_tm.tm_mon = 1;
 			week_tm.tm_year++;
@@ -304,12 +304,12 @@ set_calendar_sender_text (SunOneItipView *view)
 	case SUNONE_ITIP_VIEW_MODE_REQUEST:
 		/* FIXME is the delegator stuff handled correctly here? */
 		if (priv->delegator) {
-			sender = g_strdup_printf (_("<b>%s</b> requests the presence of %s at the following meeting."), organizer, priv->delegator);
+			sender = g_strdup_printf (_("<b>%s</b> has delegated the following meeting to you:"), priv->delegator);
 		} else {
 			if (priv->sentby)
-				sender = g_strdup_printf (_("<b>%s</b> through %s requests your presence at the following meeting."), organizer, priv->sentby);
+				sender = g_strdup_printf (_("<b>%s</b> through %s requests your presence at the following meeting:"), organizer, priv->sentby);
 			else
-				sender = g_strdup_printf (_("<b>%s</b> requests your presence at the following meeting."), organizer);
+				sender = g_strdup_printf (_("<b>%s</b> requests your presence at the following meeting:"), organizer);
 		}
 		tmp = sender;
 		sender = g_strdup_printf ("%s\n%s", sender, _("Please choose your answer from the status field of the table above."));
